@@ -2,7 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Provided email-address is not valid" : "La dirección de E Mail proporcionada no es valida",
-    "Successfully sent email to " : "E Mail enviado satisfactoriamente a",
     "Hello," : "Hola,",
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
@@ -61,7 +60,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
-    "today" : "hoy",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
@@ -73,7 +71,6 @@ OC.L10N.register(
     "Categories" : "Categoría",
     "Movie" : "Película",
     "Mail" : "Correo Electrónico",
-    "Play" : "Reproducir",
     "Global" : "Global"
 },
 "nplurals=2; plural=(n != 1);");
