@@ -5,9 +5,8 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Thư điện tử được cung cấp không khả dụng",
     "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Một lỗi không mong đợi khi đang gửi thư điện tử. Vui lòng liên hệ quản trị viên của bạn",
-    "Successfully sent email to " : "Đã hoàn thành việc gửi thư điện tử đến",
     "Hello," : "Xin chào,",
-    "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch calendar »%s«.",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch »%s«.",
     "Open »%s«" : "Mở »%s«",
     "Cheers!" : "Xin chúc mừng!",
     "Upcoming events" : "Các sự kiện sắp diễn ra",
@@ -78,6 +77,7 @@ OC.L10N.register(
     "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
     "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vui lòng nhập vào một liên kết khả dụng ( bắt đầu với http://, https://, webcal://, hoặc webcals://)",
+    "Untitled event" : "Sự kiện không tiêu đề",
     "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
     "Import calendars" : "Nhập lịch",
     "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
@@ -104,7 +104,7 @@ OC.L10N.register(
     "Month view" : "Xem theo tháng",
     "Actions" : "Hành động",
     "Create event" : "Tạo sự kiện mới",
-    "Show shortcuts" : "Hiển thị các lối tắt",
+    "Show shortcuts" : "Hiển thị các phím tắt",
     "Enable birthday calendar" : "Bật lịch sinh nhật",
     "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
     "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
@@ -137,29 +137,20 @@ OC.L10N.register(
     "_week_::_weeks_" : ["tuần"],
     "No reminders yet" : "Chưa có lịch nhắc hẹn nào ",
     "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
+    "Free" : "Rãnh",
     "Busy (tentative)" : "Bận (có khả năng thay đổi)",
     "Busy" : "Bận",
     "Out of office" : "Không ở văn phòng",
     "Unknown" : "Không xác định",
-    "{name} accepted your invitation." : "{name}  đã chấp nhận lời mởi của bạn.",
-    "{name} accepted {organizerName}'s invitation." : "{name} đã chấp nhận lời mời của {organizerName}",
-    "{name} declined your invitation." : "{name} đã từ chối lời mơi của bạn",
-    "{name} declined {organizerName}'s invitation." : "{name} đã từ chối lời mời của {organizerName}",
-    "{name} has delegated their invitation." : "{name} đã ủy thác lời mời của họ",
-    "{name} marked their participation as tentative." : "{name} đã đánh dấu sự tham dự của họ với trạng thái không chắc chắn",
-    "{name} did not respond to your invitation yet." : "{name} chưa trả lời lời mời của bạn",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} chưa trả lời cho lời mời của {organizerName}",
     "Create Talk room for this event" : "Tạo một phòng trò chuyện cho sự kiện này",
     "Show busy times" : "Cho thấy các thời gian bận",
     "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
     "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
-    "Send e-mail" : "Gửi email",
     "Chairperson" : "Chủ tịch",
     "Required participant" : "Người tham gia được yêu cầu",
     "Optional participant" : "Người tham gia không bắt buộc",
     "Non-participant" : "Người không tham gia",
     "Remove attendee" : "Gỡ bỏ người tham gia",
-    "Search for e-mails, users, contacts, resources or rooms" : "Tìm kiếm cho email, người dùng, liên hệ, nguồn lực hoặc phòng ốc",
     "No match found" : "Không có khớp lệnh nào được tìm thấy",
     "No attendees yet" : "Chưa có giờ tham gia",
     "(organizer)" : "(organizer)",
@@ -167,7 +158,6 @@ OC.L10N.register(
     "Remove color" : "Gỡ màu",
     "Event title" : "Tiêu đề sự kiện",
     "All day" : "Cả ngày",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "Không thể chỉnh sửa thiết lập cho cả-ngày dành cho các sự kiện có một phần là của sự kiện lặp lại",
     "from {startDate}" : "từ {startDate}",
     "from {startDate} at {startTime}" : "từ {startDate} vào lúc {startTime}",
     "to {endDate}" : "đến  {endDate}",
@@ -178,7 +168,6 @@ OC.L10N.register(
     "on date" : "vào ngày",
     "after" : "sau khi",
     "_time_::_times_" : ["lần"],
-    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Sự kiện này là một sự kiện không có trong chũi sự kiện lặp lại. bạn không thể thêm vào một luật lệ lặp lại cho nó. ",
     "first" : "đầu tiên",
     "third" : "vị trí thứ ba",
     "fourth" : "vị trí thứ tư",
@@ -189,15 +178,15 @@ OC.L10N.register(
     "Repeat" : "Lặp lại",
     "Repeat every" : "Lặp lại mỗi",
     "By day of the month" : "Vào ngày của tháng",
-    "On the" : "trên",
+    "On the" : "Trên",
     "_month_::_months_" : ["tháng"],
     "_year_::_years_" : ["năm"],
     "Monday" : "Thứ 2",
     "weekday" : "ngày làm việc",
     "weekend day" : "ngày cuối tuần",
-    "Summary" : "tóm tắt",
-    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Định nghĩa về định kỳ của sự kiện này không hoàn toàn được hỗ trợ bởi Nextcloud. Nếu bạn sửa các lựa chọn định kỳ này, một vài định kỳ có thể sẽ bị mất ",
-    "More" : "hơn",
+    "Summary" : "Tóm tắt",
+    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Định nghĩa về định kỳ của sự kiện này không hoàn toàn được hỗ trợ bởi vWorkspace. Nếu bạn sửa các lựa chọn định kỳ này, một vài định kỳ có thể sẽ bị mất ",
+    "More" : "Thêm",
     "Save" : "Lưu",
     "Update" : "Cập nhật",
     "Update this occurrence" : "Cập nhập định kỳ này",
@@ -205,12 +194,12 @@ OC.L10N.register(
     "Public calendar does not exist" : "Lịch công khai không tồn tại",
     "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
     "Please select a timezone:" : "Vui lòng chọn múi giờ:",
-    "Pick a time" : "chọn thời gian",
+    "Pick a time" : "Chọn thời gian",
     "Pick a date" : "Chọn ngày",
     "from {formattedDate}" : "từ {formattedDate}",
     "to {formattedDate}" : "đến {formattedDate}",
     "on {formattedDate}" : "vào {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "từ  {formattedDate} vào lúc {formattedTime}",
+    "from {formattedDate} at {formattedTime}" : "từ {formattedDate} vào lúc {formattedTime}",
     "to {formattedDate} at {formattedTime}" : "đến {formattedDate} vào lúc {formattedTime}",
     "on {formattedDate} at {formattedTime}" : "vào {formattedDate} vào lúc {formattedTime}",
     "{formattedDate} at {formattedTime}" : "{formattedDate} vào lúc {formattedTime}",
@@ -255,7 +244,7 @@ OC.L10N.register(
     "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ngày trước khi sự kiện bắt đầu vào lúc {formattedHourMinute}"],
     "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tuần trước khi sự kiện bắt đầu vào lúc {formattedHourMinute}"],
     "on the day of the event at {formattedHourMinute}" : "vào ngày sự kiện bắt đầu vào lúc {formattedHourMinute}",
-    "at the event's start" : "Vào lúc sự kiện bắt đầu",
+    "at the event's start" : "vào lúc sự kiện bắt đầu",
     "at the event's end" : "vào lúc sự kiện kết thúc",
     "{time} before the event starts" : "{time} trước khi sự kiện bắt đầu",
     "{time} before the event ends" : "{time} trước khi sự kiện kết thúc",
@@ -275,26 +264,17 @@ OC.L10N.register(
     "_Every %n year_::_Every %n years_" : ["Mỗi %n năm"],
     "_on {weekday}_::_on {weekdays}_" : ["vào  {weekdays}"],
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["vào các ngày {dayOfMonthList}"],
-    "on the {ordinalNumber} {byDaySet}" : "vào  {ordinalNumber} {byDaySet}",
+    "on the {ordinalNumber} {byDaySet}" : "vào {ordinalNumber} {byDaySet}",
     "in {monthNames}" : "trong {monthNames}",
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "trong {monthNames} trên {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "cho đến {untilDate}",
     "_%n time_::_%n times_" : ["%n lần"],
-    "Untitled event" : "Sự kiện không tiêu đề",
     "Untitled task" : "Nhiệm vụ không tiêu đề",
     "Please ask your administrator to enable the Tasks App." : "Vui lòng hỏi quản trị viên của bạn để bật ứng dụng Nhiệm Vụ",
-    "prev" : "trước",
-    "next" : "tiếp theo",
-    "prev year" : "năm trước",
-    "next year" : "năm tới",
-    "today" : "hôm nay",
-    "list" : "danh sách",
-    "W" : "w",
-    "all-day" : "nguyên-ngày",
     "%n more" : "thêm %n",
     "No events to display" : "không có sự kiện để hiển thị",
     "_+%n more_::_+%n more_" : ["+ thêm %n "],
-    "No events" : "không có sự kiện",
+    "No events" : "Không có sự kiện",
     "Create a new event or change the visible time-range" : "Tạo sự kiện mới hoặc thay đổi khung thời gian hiển thị",
     "It might have been deleted, or there was a typo in a link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
     "It might have been deleted, or there was a typo in the link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
@@ -314,7 +294,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Sự xác nhận về tình trạng tổng thể của sự kiện.",
     "Show as" : "Cho thấy với",
     "Take this event into account when calculating free-busy information." : "Lưu ý sự kiện này vào tài khoản khi tính toán về thông tin bận-rãnh",
-    "Free" : "Rãnh",
     "Categories" : "Các hạng mục",
     "Categories help you to structure and organize your events." : "Các hạng mục này giúp bạn lên sườn và sắp xếp các sự kiện của bạn",
     "Search or add categories" : "Tìm kiếm và thêm vào các hạng mục",
@@ -323,7 +302,7 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Dùng màu đặc biệt cho sự kiện này. Ghi đè lên màu hiện hành",
     "Chat room for event" : "Phòng trò chuyện cho sự kiện",
     "Imported {filename}" : " {filename} đã được nhập",
-    "Meditation" : "Thiền",
+    "Meditation" : "Suy nghĩ",
     "Relaxing" : "Thư giãn",
     "Relax" : "Thư giãn",
     "Presentation" : "Buổi thuyết trình",
@@ -342,14 +321,10 @@ OC.L10N.register(
     "Review" : "Đánh giá",
     "Office" : "Văn phòng",
     "Contributor week" : "Tuần lễ đóng góp",
-    "Party" : "Tiệc tùng",
-    "Celebration" : "Lễ kỉ niệm",
     "Mail" : "Thư điện tử",
     "Soccer" : "Đá banh",
     "Football" : "Bóng bầu dục",
     "Gaming" : "Chơi game",
-    "Play" : "Play",
-    "Game" : "Trò chơi",
     "Drive" : "Lái xe",
     "Bicycle" : "Xep đạp",
     "Cycle" : "Đi xe đạp",
@@ -403,6 +378,8 @@ OC.L10N.register(
     "Lecture" : "Bài giảng",
     "Seminar" : "Hội thảo",
     "Photograph" : "Bức ảnh",
+    "Party" : "Tiệc tùng",
+    "Celebration" : "Lễ kỉ niệm",
     "Celebrate" : "Ăn mừng",
     "Shopping" : "Đi mua sắm",
     "Skate" : "Đi trượt ván",
